@@ -148,7 +148,7 @@ class BPE:
 
     def update(
         self,
-        chars: Union[Text, CharsInput, List[CharsInput]],
+        chars: Union[Text, TextInput, List[CharsInput]],
         pairs: Union[Char, CharsOutput]
     ) -> Union[CharsOutput, List[CharsOutput]]:
         if isinstance(chars, str):
@@ -157,6 +157,7 @@ class BPE:
             first_element = chars[0]
             if isinstance(first_element, (str, list, tuple, np.ndarray, pd.Series)):
                 return [self._update(_, pairs) for _ in chars]
+                # return self._update(chars, pairs)
             else:
                 raise ValueError(
                     f"type of chars element unknown: {type(first_element)}. "
@@ -317,14 +318,14 @@ class TokenizerBPE(TokenizerBase, BPE):
         """
         return self._get_pairs(chars, **kwargs)
 
-    def tokenize(self, text: Text, **kwargs) -> TokenOutput:
+    def _tokenize(self, texts: Union[Text, CharsInput], **kwargs) -> CharsOutput:
         """
         Split a string into char, then merge pair char by ordered vocab until no more find.
         Replacing unknown tokens with the :obj:`unk_token`.
         """
         convert_unknown = kwargs.get('convert_unknown', CONVERT_UNKNOWN_DEFAULT)
 
-        def merge(chars: CharsInput, **kwargs) -> CharsOutput:
+        def merge(chars: Union[Text, CharsInput], **kwargs) -> CharsOutput:
             """
             Merge pair char by ordered vocab.
             """
@@ -333,7 +334,7 @@ class TokenizerBPE(TokenizerBase, BPE):
                 need_merge, chars = _merge(chars, **kwargs)
             return chars
 
-        def _merge(chars: CharsInput, **kwargs) -> CharsOutput:
+        def _merge(chars: Union[Text, CharsInput], **kwargs) -> CharsOutput:
             """
             Use trained vocabulary makes it different from get_pairs().
             The importance of Token has already been recorded by vocab order.
@@ -342,14 +343,14 @@ class TokenizerBPE(TokenizerBase, BPE):
             if not pairs: return False, chars
 
             pairs = self.get_pairs(pairs)
-            chars = self.update(chars, pairs)
+            chars = self._update(chars, pairs)
             return True, chars
 
-        def to_unknown(chars: CharsInput, vocab: Vocabulary):
+        def to_unknown(chars: Union[Text, CharsInput], vocab: Vocabulary):
             # TODO: to be implement with transformers
             return [c if c in self.vocab else self.vocab.unk_token for c in chars]
 
-        chars = self.to_char(text)
+        chars = self.to_char(texts)
         chars = merge(chars)
         if convert_unknown:
             chars = to_unknown(chars, self.vocab)
