@@ -1,9 +1,11 @@
 # encoding: utf-8
 
 import os
+import pickle
 import numpy as np
 import pandas as pd
 
+from pathlib import Path
 from typing import List, Union, Tuple, Optional
 from collections import OrderedDict
 from collections.abc import Iterable
@@ -101,8 +103,19 @@ class VocabularyBase:
                 self._create_vocab(new_texts, **kwargs)
 
         def _create_vocab_byfile(p, **kwargs):
-            with p.open() as f:
-                texts = f.readlines()
+            # TODO: support by kwargs
+            # with p.open() as f:
+            #     texts = f.readlines()
+            with p.open('rb') as f:
+                texts = pickle.load(f)
+            _create_vocab_with_special(texts, **kwargs)
+
+        def _create_vocab_bydir(p, **kwargs):
+            # TODO: support by kwargs
+            texts = []
+            for _ in p.iterdir():
+                with _.open('rb') as f:
+                    texts.extend(pickle.load(f))
             _create_vocab_with_special(texts, **kwargs)
 
         if isinstance(texts_or_path, (list, tuple, np.ndarray, pd.Series)):
@@ -110,10 +123,11 @@ class VocabularyBase:
         else:
             p = Path(texts_or_path)
             if p.is_file():
-                self._create_vocab_byfile(p, **kwargs)
+                _create_vocab_byfile(p, **kwargs)
             elif p.is_dir():
-                # TODO: in 1 file
-                for _ in p.iterdir(): self._create_vocab_byfile(_, **kwargs)
+                # TODO:
+                # for _ in p.iterdir(): _create_vocab_byfile(_, **kwargs)
+                _create_vocab_bydir(p, **kwargs)
             else:
                 raise ValueError(
                     f"type of texts_or_path unknown: {type(texts_or_path)}. "
